@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2025 Aspose.Cells Cloud
+Copyright (c) 2026 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -37,7 +37,8 @@ use Date::Parse;
 use DateTime;
 use AsposeCellsCloud::Object::BaseOperateOptions;
 use AsposeCellsCloud::Object::DataSource;
-use AsposeCellsCloud::Object::FileInfo; 
+use AsposeCellsCloud::Object::FileInfo;
+use AsposeCellsCloud::Object::ScopeOptions; 
 
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
@@ -137,35 +138,21 @@ __PACKAGE__->method_documentation({
      'data_source' => {
      	datatype => 'DataSource',
      	base_name => 'DataSource',
-     	description => '',
+     	description => 'Represents data source.  There are three types of data, they are CloudFileSystem, RequestFiles, HttpUri.',
      	format => '',
      	read_only => '',
      		},
      'file_info' => {
      	datatype => 'FileInfo',
      	base_name => 'FileInfo',
-     	description => '',
+     	description => 'Represents file information. Include of filename, filesize, and file content(base64String).',
      	format => '',
      	read_only => '',
      		},
-     'worksheet' => {
-     	datatype => 'string',
-     	base_name => 'Worksheet',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'remove_duplicates_area' => {
-     	datatype => 'string',
-     	base_name => 'RemoveDuplicatesArea',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'remove_duplicates_area_value' => {
-     	datatype => 'string',
-     	base_name => 'RemoveDuplicatesAreaValue',
-     	description => '',
+     'scope_options' => {
+     	datatype => 'ScopeOptions',
+     	base_name => 'ScopeOptions',
+     	description => 'Specifies the range of cells within the worksheet where the spreadsheet operations will be performed. This parameter allows users to define the exact area to be processed, ensuring that operations are applied only to the designated cells.',
      	format => '',
      	read_only => '',
      		},    
@@ -175,18 +162,14 @@ __PACKAGE__->swagger_types( {
     'name' => 'string',
     'data_source' => 'DataSource',
     'file_info' => 'FileInfo',
-    'worksheet' => 'string',
-    'remove_duplicates_area' => 'string',
-    'remove_duplicates_area_value' => 'string' 
+    'scope_options' => 'ScopeOptions' 
 } );
 
 __PACKAGE__->attribute_map( {
     'name' => 'Name',
     'data_source' => 'DataSource',
     'file_info' => 'FileInfo',
-    'worksheet' => 'Worksheet',
-    'remove_duplicates_area' => 'RemoveDuplicatesArea',
-    'remove_duplicates_area_value' => 'RemoveDuplicatesAreaValue' 
+    'scope_options' => 'ScopeOptions' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
