@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2025 Aspose.Cells Cloud
+Copyright (c) 2026 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents save result.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'SaveResult',
                                   required => [], # TODO
 }                                 );
@@ -128,7 +128,7 @@ __PACKAGE__->method_documentation({
      'documents' => {
      	datatype => 'ARRAY[CellsCloudFileInfo]',
      	base_name => 'Documents',
-     	description => 'Represents cells cloud file infomation.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
