@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2025 Aspose.Cells Cloud
+Copyright (c) 2026 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -72,6 +73,8 @@ sub new {
 # GetWorkbookRequest.region : The regional settings for workbook.  ,
 # GetWorkbookRequest.pageWideFitOnPerSheet : The page wide fit on worksheet.  ,
 # GetWorkbookRequest.pageTallFitOnPerSheet : The page tall fit on worksheet.  ,
+# GetWorkbookRequest.onePagePerSheet : When converting to PDF format, one page per sheet.  ,
+# GetWorkbookRequest.onlyAutofitTable :   ,
 # GetWorkbookRequest.FontsLocation : Use Custom fonts.   
 
 {
@@ -95,7 +98,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/{name}';
+    my $_resource_path = 'v3.0/cells/{name}';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -161,10 +164,21 @@ sub run_http_request {
         $query_params->{'pageTallFitOnPerSheet'} = $client->to_query_value($self->page_tall_fit_on_per_sheet);      
     }
 
+    if(defined $self->one_page_per_sheet){
+        $query_params->{'onePagePerSheet'} = $client->to_query_value($self->one_page_per_sheet);      
+    }
+
+    if(defined $self->only_autofit_table){
+        $query_params->{'onlyAutofitTable'} = $client->to_query_value($self->only_autofit_table);      
+    }
+
     if(defined $self->fonts_location){
         $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
     } 
     my $_body_data;
+
+ 
+
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -266,6 +280,20 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'one_page_per_sheet' => {
+     	datatype => 'string',
+     	base_name => 'onePagePerSheet',
+     	description => 'When converting to PDF format, one page per sheet.',
+     	format => '',
+     	read_only => '',
+     		},
+     'only_autofit_table' => {
+     	datatype => 'string',
+     	base_name => 'onlyAutofitTable',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'fonts_location' => {
      	datatype => 'string',
      	base_name => 'FontsLocation',
@@ -290,6 +318,8 @@ __PACKAGE__->attribute_map( {
     'region' => 'region',
     'page_wide_fit_on_per_sheet' => 'pageWideFitOnPerSheet',
     'page_tall_fit_on_per_sheet' => 'pageTallFitOnPerSheet',
+    'one_page_per_sheet' => 'onePagePerSheet',
+    'only_autofit_table' => 'onlyAutofitTable',
     'fonts_location' => 'FontsLocation' 
 } );
 
