@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2025 Aspose.Cells Cloud
+Copyright (c) 2026 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -150,10 +150,14 @@ sub run_http_request {
     my $_body_data;
 
 
-    $form_params->{basename($self->datafile)} = [$self->datafile ,basename($self->datafile),'application/octet-stream'];
+    if (defined $self->datafile) {   
+        $form_params->{basename($self->datafile)} = [$self->datafile ,basename($self->datafile),'application/octet-stream'];
+    }
 
 
-    $form_params->{basename($self->spreadsheet)} = [$self->spreadsheet ,basename($self->spreadsheet),'application/octet-stream'];
+    if (defined $self->spreadsheet) {   
+        $form_params->{basename($self->spreadsheet)} = [$self->spreadsheet ,basename($self->spreadsheet),'application/octet-stream'];
+    }
  
 
     # authentication setting, if any
