@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2025 Aspose.Cells Cloud
+Copyright (c) 2026 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -59,7 +60,7 @@ sub new {
 
 
 # Run Operation Request
-# PostAddTextContentRequest.addTextOptions :    
+# PostAddTextContentRequest.addTextOptions : that specifies the text content and the position where the text should be added.   
 
 {
     my $params = {
@@ -70,7 +71,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_add_text_content' } = { 
-    	summary => 'Adds text content to a workbook at specified positions within cells based on provided options using ASP.NET Core Web API.',
+    	summary => 'Adds text content to a specified location within a document. It requires an object that defines the text to be added and the insertion location.',
         params => $params,
         returns => 'FileInfo',
     };
@@ -82,7 +83,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/addtext';
+    my $_resource_path = 'v3.0/cells/addtext';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -99,11 +100,14 @@ sub run_http_request {
  
     my $_body_data;
 
+
     # body params
     if (defined $self->add_text_options) {
-        #$_body_data = $self->add_text_options;
          $_body_data = JSON->new->convert_blessed->encode( $self->add_text_options);
     }
+
+ 
+
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -117,7 +121,7 @@ __PACKAGE__->method_documentation({
      'add_text_options' => {
      	datatype => 'AddTextOptions',
      	base_name => 'addTextOptions',
-     	description => '',
+     	description => 'that specifies the text content and the position where the text should be added.',
      	format => '',
      	read_only => '',
      		},    
