@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2025 Aspose.Cells Cloud
+Copyright (c) 2026 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -122,10 +122,13 @@ sub run_http_request {
 
     # body params
     if (defined $self->cells_documents) {
-         $form_params->{'cellsDocuments'} = JSON->new->convert_blessed->encode( $self->cells_documents) ;
+         $_body_data = JSON->new->convert_blessed->encode( $self->cells_documents);
+         $form_params->{'cellsDocuments'} = $_body_data ;
     }
 
-    $form_params->{basename($self->file)} = [$self->file ,basename($self->file),'application/octet-stream'];
+    if (defined $self->file) {   
+        $form_params->{basename($self->file)} = [$self->file ,basename($self->file),'application/octet-stream'];
+    }
  
 
     # authentication setting, if any
